@@ -100,7 +100,7 @@ void LevelSet::reset()
 
 bool LevelSet::load(const QString& levelSetName)
 {
-    QString file = QStandardPaths::locate(QStandardPaths::DataLocation, QString("levels/%1.dat").arg(levelSetName));
+    QString file = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("levels/%1.dat").arg(levelSetName));
     if (file.isEmpty())
     {
         qDebug() << "level set \"" << levelSetName << "\" data file not found. Check your installation";
@@ -242,7 +242,7 @@ const Molecule* LevelSet::readLevelMolecule(int levelNum) const
         current.obj = value.at(0).toLatin1();
         value = value.mid(2);
 
-        strncpy(current.conn, value.toAscii(), sizeof(current.conn));
+        strncpy(current.conn, value.toLatin1(), sizeof(current.conn));
         if (mol->m_atoms.indexOf(current) != -1)
              qWarning()
             << "OOOPS, duplicate atom definition in" << key;
@@ -288,7 +288,7 @@ const Molecule* LevelSet::readLevelMolecule(int levelNum) const
 
 bool LevelSet::isDefaultLevelsAvailable()
 {
-    QString file = QStandardPaths::locate(QStandardPaths::DataLocation, QString("levels/%1.dat").arg(DEFAULT_LEVELSET_NAME));
+    QString file = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("levels/%1.dat").arg(DEFAULT_LEVELSET_NAME));
     if (file.isEmpty())
     {
         //qDebug() << "default level set \"" << DEFAULT_LEVELSET_NAME << "\" data file not found. Check your installation";
