@@ -47,7 +47,7 @@ struct Theme : public KgTheme
 {
 	Theme() : KgTheme("pics/default_theme.desktop")
 	{
-		setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, "pics/default_theme.svgz"));
+		setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("pics/default_theme.svgz")));
 	}
 };
 
@@ -156,7 +156,7 @@ void PlayField::updateFieldItems()
 
 void PlayField::updateBackground()
 {
-    setBackgroundBrush(m_renderer.spritePixmap("background", sceneRect().size().toSize()));
+    setBackgroundBrush(m_renderer.spritePixmap(QStringLiteral("background"), sceneRect().size().toSize()));
 }
 
 void PlayField::resize( int width, int height)
@@ -211,14 +211,14 @@ void PlayField::nextAtom()
 
     while(1)
     {
-        AtomFieldItem* item = 0;
         for(int y=ys; y<FIELD_SIZE; ++y )
         {
             int px = toPixX(x)+m_elemSize/2;
             int py = toPixY(y)+m_elemSize/2;
-            item = qgraphicsitem_cast<AtomFieldItem*>( itemAt(px, py) );
-            if( item != 0 )
+            const QList<QGraphicsItem *> itemsAtPoint = items(QPointF(px, py));
+            if( !itemsAtPoint.isEmpty() )
             {
+                AtomFieldItem* item = qgraphicsitem_cast<AtomFieldItem*>( itemsAtPoint[0] );
                 m_selIdx = m_atoms.indexOf(item);
                 updateArrows();
                 // if this atom can't move, we won't return - we'll search further
@@ -254,21 +254,24 @@ void PlayField::previousAtom()
 
     while(1)
     {
-        AtomFieldItem* item = 0;
         for(int y=ys; y>=0; --y )
         {
             int px = toPixX(x)+m_elemSize/2;
             int py = toPixY(y)+m_elemSize/2;
-            item = qgraphicsitem_cast<AtomFieldItem*>( itemAt(px, py) );
-            if( item != 0 && item->atomNum() != -1 )
+            const QList<QGraphicsItem *> itemsAtPoint = items(QPointF(px, py));
+            if( !itemsAtPoint.isEmpty() )
             {
-                m_selIdx = m_atoms.indexOf(item);
-                updateArrows();
-                // if this atom can't move, we won't return - we'll search further
-                // until we found moveable one
-                if( m_upArrow->isVisible() || m_rightArrow->isVisible()
-                        || m_downArrow->isVisible() || m_leftArrow->isVisible() )
-                    return;
+                AtomFieldItem* item = qgraphicsitem_cast<AtomFieldItem*>( itemsAtPoint[0] );
+                if ( item->atomNum() != -1 )
+                {
+                    m_selIdx = m_atoms.indexOf(item);
+                    updateArrows();
+                    // if this atom can't move, we won't return - we'll search further
+                    // until we found moveable one
+                    if( m_upArrow->isVisible() || m_rightArrow->isVisible()
+                            || m_downArrow->isVisible() || m_leftArrow->isVisible() )
+                        return;
+                }
             }
         }
         x--;
@@ -420,11 +423,11 @@ void PlayField::mousePressEvent( QGraphicsSceneMouseEvent* ev )
     if( isAnimating() || m_levelFinished )
         return;
 
-    QGraphicsItem* clickedItem = itemAt(ev->scenePos());
-    if(!clickedItem)
+    const QList<QGraphicsItem *> itemsAtPoint = items(ev->scenePos());
+    if(itemsAtPoint.isEmpty())
         return;
 
-    AtomFieldItem *atomItem = qgraphicsitem_cast<AtomFieldItem*>(clickedItem);
+    AtomFieldItem *atomItem = qgraphicsitem_cast<AtomFieldItem*>(itemsAtPoint[0]);
     if( atomItem ) // that is: atom selected
     {
         m_selIdx = m_atoms.indexOf( atomItem );
@@ -432,7 +435,7 @@ void PlayField::mousePressEvent( QGraphicsSceneMouseEvent* ev )
         return;
     }
 
-    ArrowFieldItem *arrowItem = qgraphicsitem_cast<ArrowFieldItem*>(clickedItem);
+    ArrowFieldItem *arrowItem = qgraphicsitem_cast<ArrowFieldItem*>(itemsAtPoint[0]);
     if( arrowItem == m_upArrow )
     {
         moveSelectedAtom( Up );
@@ -681,7 +684,7 @@ void PlayField::drawForeground( QPainter *p, const QRectF&)
         return;
     }
 
-    QPixmap aPix = m_renderer.spritePixmap("wall", QSize(m_elemSize, m_elemSize));
+    QPixmap aPix = m_renderer.spritePixmap(QStringLiteral("wall"), QSize(m_elemSize, m_elemSize));
     for (int i = 0; i < FIELD_SIZE; i++)
         for (int j = 0; j < FIELD_SIZE; j++)
             if(m_levelData->containsWallAt(i,j))
@@ -704,7 +707,7 @@ void PlayField::saveGame( KConfigGroup& config ) const
         // we'll write pos through using QPoint
         // I'd use QPair but it isn't supported by QVariant
         QPoint pos(m_atoms.at(idx)->fieldX(), m_atoms.at(idx)->fieldY());
-        config.writeEntry( QString("Atom_%1").arg(idx), pos);
+        config.writeEntry( QStringLiteral("Atom_%1").arg(idx), pos);
     }
 
     // save undo history
@@ -717,7 +720,7 @@ void PlayField::saveGame( KConfigGroup& config ) const
         // atomIdx, direction, numCells
         QList<int> move;
         move << mv.atomIdx << static_cast<int>(mv.dir) << mv.numCells;
-        config.writeEntry( QString("Move_%1").arg(i), move );
+        config.writeEntry( QStringLiteral("Move_%1").arg(i), move );
     }
     config.writeEntry("SelectedAtom", m_selIdx);
     config.writeEntry("LevelFinished", m_levelFinished );
@@ -731,7 +734,7 @@ void PlayField::loadGame( const KConfigGroup& config )
     // read atom positions
     for(int idx=0; idx<m_atoms.count(); ++idx)
     {
-        QPoint pos = config.readEntry( QString("Atom_%1").arg(idx), QPoint() );
+        QPoint pos = config.readEntry( QStringLiteral("Atom_%1").arg(idx), QPoint() );
         m_atoms.at(idx)->setFieldXY(pos.x(), pos.y());
         m_atoms.at(idx)->setPos( toPixX(pos.x()), toPixY(pos.y()) );
     }
@@ -741,7 +744,7 @@ void PlayField::loadGame( const KConfigGroup& config )
     AtomMove mv;
     for(int i=0;i<m_numMoves;++i)
     {
-        QList<int> move = config.readEntry( QString("Move_%1").arg(i), QList<int>() );
+        QList<int> move = config.readEntry( QStringLiteral("Move_%1").arg(i), QList<int>() );
         mv.atomIdx = move.at(0);
         mv.dir = static_cast<Direction>(move.at(1));
         mv.numCells = move.at(2);
